@@ -78,7 +78,7 @@ class GatewayServer(threading.Thread):
     handler = self.handlers[path]
     try:
       raw_output = self.client.request(handler['service'], handler['method'], input, raw_output=True)
-      output = MessageToDict(raw_output, including_default_value_fields=True, preserving_proto_field_name=True)
+      output = MessageToDict(raw_output, preserving_proto_field_name=True)
       return JSONResponse(output)
     except Exception as ex:
       grpc_status = ex._state.code.name
